<?php

declare(strict_types=1);

namespace Drupal\schemadotorg_taxonomy;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Render\BubbleableMetadata;

/**
 * Schema.org taxonomy JSON-LD manager interface.
 */
interface SchemaDotOrgTaxonomyJsonLdManagerInterface {

  /**
   * Load Schema.org JSON-LD for an entity.
   *
   * @param array $data
   *   Schema.org type data.
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *   The entity.
   * @param \Drupal\Core\Render\BubbleableMetadata $bubbleable_metadata
   *   Object to collect JSON-LD's bubbleable metadata.
   */
  public function load(array &$data, EntityInterface $entity, BubbleableMetadata $bubbleable_metadata): void;

  /**
   * Alter Schema.org JSON-LD for an entity.
   *
   * @param array $data
   *   Schema.org type data.
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *   The entity.
   */
  public function alter(array &$data, EntityInterface $entity): void;

  /**
   * Preprocess block alter JSON-LD preview Term endpoint.
   *
   * @param array $variables
   *   An array of variables.
   */
  public function preprocessBlock(array &$variables): void;

}
