<?php

declare(strict_types=1);

namespace Drupal\Tests\schemadotorg_webpage\Kernel;

use Drupal\node\Entity\Node;
use Drupal\Tests\schemadotorg_jsonld\Kernel\SchemaDotOrgJsonLdKernelTestBase;

/**
 * Tests the functionality of the Schema.org WebPage JSON-LD.
 *
 * @covers schemadotorg_webpage_schemadotorg_jsonld_alter
 * @group schemadotorg
 */
class SchemaDotOrgWebPageJsonLdKernelTest extends SchemaDotOrgJsonLdKernelTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'schemadotorg_webpage',
    'schemadotorg_jsonld_breadcrumb',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->installConfig(['schemadotorg_webpage']);
    $this->manager = $this->container->get('schemadotorg_jsonld.manager');
    $this->builder = $this->container->get('schemadotorg_jsonld.builder');
  }

  /**
   * Test Schema.org WebPage.
   */
  public function testWebPage(): void {
    \Drupal::currentUser()->setAccount($this->createUser(['access content']));

    $mapping = $this->createSchemaEntity('node', 'Recipe');

    $node = Node::create([
      'type' => 'recipe',
      'title' => 'Some recipe',
    ]);
    $node->save();

    /* ********************************************************************** */

    // Check that the JSON-LD WebPage is built with the
    // breadcrumb and mainEntity properties.
    $route_match = $this->manager->getEntityRouteMatch($node);
    $jsonld = $this->builder->build($route_match);
    $this->assertEquals('WebPage', $jsonld['@type']);
    $this->assertEquals('BreadcrumbList', $jsonld['breadcrumb']['@type']);
    $this->assertEquals('Recipe', $jsonld['mainEntity']['@type']);

    // Check that the JSON-LD WebPage subtyping works as expected with
    // a sub type.
    $mapping
      ->setThirdPartySetting('schemadotorg_webpage', 'schema_subtype', 'MedicalWebPage')
      ->save();
    $route_match = $this->manager->getEntityRouteMatch($node);
    $jsonld = $this->builder->build($route_match);
    $this->assertEquals('MedicalWebPage', $jsonld['@type']);

    // Check that the JSON-LD WebPage subtyping works as expected with
    // an additional type.
    $mapping
      ->setThirdPartySetting('schemadotorg_webpage', 'schema_subtype', 'NotAWebPage')
      ->save();
    $route_match = $this->manager->getEntityRouteMatch($node);
    $jsonld = $this->builder->build($route_match);
    $this->assertEquals('WebPage', $jsonld['@type']);
    $this->assertEquals('NotAWebPage', $jsonld['additionalType']);
  }

}
