<?php

declare(strict_types=1);

namespace Drupal\Tests\schemadotorg_webpage\Kernel;

use Drupal\field\Entity\FieldConfig;
use Drupal\Tests\schemadotorg\Kernel\SchemaDotOrgEntityKernelTestBase;

/**
 * Tests the functionality of the Schema.org WebPage support.
 *
 * @group schemadotorg
 */
class SchemaDotOrgWebPageKernelTest extends SchemaDotOrgEntityKernelTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = ['schemadotorg_webpage'];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->installConfig(['schemadotorg_webpage']);
  }

  /**
   * Test Schema.org WebPage support.
   */
  public function testWebPage(): void {
    $mapping = $this->createSchemaEntity('node', 'Recipe');

    // Check that Schema.org WebPage mapping is saved as a third party setting.
    $expected_schema_properties = [
      'created' => 'dateCreated',
      'changed' => 'dateModified',
      'langcode' => 'inLanguage',
      'title' => 'name',
      'schema_image' => 'primaryImageOfPage',
      'schema_related_link' => 'relatedLink',
      'schema_significant_link' => 'significantLink',
    ];
    $this->assertEquals(
      $expected_schema_properties,
      $mapping->getThirdPartySetting('schemadotorg_webpage', 'schema_properties')
    );

    $expected_schema_properties = [
      'schema_cooking_method' => 'cookingMethod',
      'schema_cook_time' => 'cookTime',
      'created' => 'dateCreated',
      'changed' => 'dateModified',
      'schema_image' => 'image',
      'langcode' => 'inLanguage',
      'schema_is_family_friendly' => 'isFamilyFriendly',
      'title' => 'name',
      'schema_nutrition' => 'nutrition',
      'schema_prep_time' => 'prepTime',
      'schema_recipe_category' => 'recipeCategory',
      'schema_recipe_cuisine' => 'recipeCuisine',
      'schema_recipe_ingredient' => 'recipeIngredient',
      'schema_recipe_instructions' => 'recipeInstructions',
      'schema_recipe_yield' => 'recipeYield',
      'schema_suitable_for_diet' => 'suitableForDiet',
      'body' => 'text',
      'schema_total_time' => 'totalTime',
    ];
    $this->assertEquals(
      $expected_schema_properties,
      $mapping->getSchemaProperties()
    );

    // Check that the expected WebPage and Recipe fields were created.
    $field_config = FieldConfig::loadMultiple();
    $expected_field_names = [
       'node.recipe.body',
       'node.recipe.schema_cooking_method',
       'node.recipe.schema_cook_time',
       'node.recipe.schema_image',
       'node.recipe.schema_is_family_friendly',
       'node.recipe.schema_nutrition',
       'node.recipe.schema_prep_time',
       'node.recipe.schema_recipe_category',
       'node.recipe.schema_recipe_cuisine',
       'node.recipe.schema_recipe_ingredient',
       'node.recipe.schema_recipe_instructions',
       'node.recipe.schema_recipe_yield',
       'node.recipe.schema_related_link',
       'node.recipe.schema_significant_link',
       'node.recipe.schema_suitable_for_diet',
       'node.recipe.schema_total_time',
    ];
    $actual_field_names = array_keys($field_config);
    $this->assertEquals($expected_field_names, $actual_field_names);
  }

}
